<?php

namespace Boomee\Services\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Boomee\Services\Interfaces\ServiceRepositoryInterface;

class ServicePublicController extends BaseController
{
    // use ServiceWorkflow;

    /**
     * Constructor.
     *
     * @param type \Boomee\Service\Interfaces\ServiceRepositoryInterface $service
     *
     * @return type
     */
    public function __construct(ServiceRepositoryInterface $service)
    {
        $this->repository = $service;
        parent::__construct();
    }

    /**
     * Show service's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $services = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('services::service.names'))
            ->view('services::public.service.index')
            ->data(compact('services'))
            ->output();
    }


    /**
     * Show service.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $service = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($service->name . trans('services::service.name'))
            ->view('services::public.service.show')
            ->data(compact('service'))
            ->output();
    }

}
