<?php

namespace Boomee\Services\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Boomee\Services\Models\Services;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Boomee\Services\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/services/deal/*')) {
            Route::bind('deal', function ($deal) {
                $dealrepo = $this->app->make('Boomee\Services\Interfaces\DealRepositoryInterface');
                return $dealrepo->findorNew($deal);
            });
        }

        if (Request::is('*/services/service/*')) {
            Route::bind('service', function ($service) {
                $servicerepo = $this->app->make('Boomee\Services\Interfaces\ServiceRepositoryInterface');
                return $servicerepo->findorNew($service);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
